==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/ur.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "lightbox کے gallary کی پیرامیٹرز انتظام کریں");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "گیلری، نگارخانہ انتظام کریں");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "مکمل سائز کی تصویر کی چوڑائی");
define('MANAGE_GALLERY_FULL_HEIGHT', "مکمل سائز کی تصویر کی اونچائی");
define('MANAGE_GALLERY_THUMB_WIDTH', "تھمب نیل تصویر کی چوڑائی");
define('MANAGE_GALLERY_THUMB_HEIGHT', "تھمب نیل تصویر کی اونچائی");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "انگوٹھے پہلو تناسب کو برقرار رکھیں");
define('MANAGE_GALLERY_SHOW_TITLES', "عنوانات دکھائیں");
define('MANAGE_GALLERY_DISABLE_SORT', "غیر فعال چھانٹیں");
define('MANAGE_GALLERY_DELETE_IMAGE', "تصویر کو خارج");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "ترتیب دیں حکم کو محفوظ کریں");
define('MANAGE_GALLERY_PUBLISH_MSG', "شائع کرنے کی &#39;اپ ڈیٹ&#39; پر کلک کریں <br /> آپ کی اپ لوڈ کی تصاویر.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "تمام تصاویر تبدیل کیا گیا ہے اور تراتیب کو محفوظ کیا گیا ہے.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "نیا سائز تصاویر یا بچت کی ترتیبات میں ایک خامی تھی.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "آپ کی تصویر (ے) اپ لوڈ ہوگیا ہے.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "آپ کی تصویر (ے) اپ لوڈ کرنے میں ایک خامی تھی.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "آپ نے جو فائل اپ لوڈ کرنے کے کوشش کر رہے ہیں ایک تصویر نہیں ہے.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "آپ نے جو فائل اپ لوڈ کرنے کے کوشش کر رہے ہیں بہت بڑی ہے.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "عنوان محفوظ ہوگیا ہے.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "کیا آپ کو یقین ہے کہ آپ تصویر حذف کرنا چاہتے ہیں");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "؟");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "تصویر حذف کردیا گیا ہے.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "تصویر حذف کرنے میں ایک خامی تھی.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "پیرامیٹرز کو محفوظ کر رہا ہے اور نیا سائز تصاویر، براہ کرم انتظار کریں ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "اپ لوڈ، براہ کرم انتظار کریں ....");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "ترتیب کو محفوظ نہیں کیا گیا ہے. آپ ترتیب کو بچانے کے لئے چاہتے ہیں؟");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "تصویر قسم کا حکم محفوظ ہوگیا ہے.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "تصویر چھانٹیں محفوظ کرنے میں ایک خامی تھی.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/ur.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "lightbox کے gallary کی پیرامیٹرز انتظام کریں");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "گیلری، نگارخانہ انتظام کریں");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "مکمل سائز کی تصویر کی چوڑائی");
define('MANAGE_GALLERY_FULL_HEIGHT', "مکمل سائز کی تصویر کی اونچائی");
define('MANAGE_GALLERY_THUMB_WIDTH', "تھمب نیل تصویر کی چوڑائی");
define('MANAGE_GALLERY_THUMB_HEIGHT', "تھمب نیل تصویر کی اونچائی");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "انگوٹھے پہلو تناسب کو برقرار رکھیں");
define('MANAGE_GALLERY_SHOW_TITLES', "عنوانات دکھائیں");
define('MANAGE_GALLERY_DISABLE_SORT', "غیر فعال چھانٹیں");
define('MANAGE_GALLERY_DELETE_IMAGE', "تصویر کو خارج");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "ترتیب دیں حکم کو محفوظ کریں");
define('MANAGE_GALLERY_PUBLISH_MSG', "شائع کرنے کی &#39;اپ ڈیٹ&#39; پر کلک کریں <br /> آپ کی اپ لوڈ کی تصاویر.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "تمام تصاویر تبدیل کیا گیا ہے اور تراتیب کو محفوظ کیا گیا ہے.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "نیا سائز تصاویر یا بچت کی ترتیبات میں ایک خامی تھی.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "آپ کی تصویر (ے) اپ لوڈ ہوگیا ہے.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "آپ کی تصویر (ے) اپ لوڈ کرنے میں ایک خامی تھی.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "آپ نے جو فائل اپ لوڈ کرنے کے کوشش کر رہے ہیں ایک تصویر نہیں ہے.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "آپ نے جو فائل اپ لوڈ کرنے کے کوشش کر رہے ہیں بہت بڑی ہے.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "عنوان محفوظ ہوگیا ہے.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "کیا آپ کو یقین ہے کہ آپ تصویر حذف کرنا چاہتے ہیں");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "؟");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "تصویر حذف کردیا گیا ہے.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "تصویر حذف کرنے میں ایک خامی تھی.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "پیرامیٹرز کو محفوظ کر رہا ہے اور نیا سائز تصاویر، براہ کرم انتظار کریں ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "اپ لوڈ، براہ کرم انتظار کریں ....");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "ترتیب کو محفوظ نہیں کیا گیا ہے. آپ ترتیب کو بچانے کے لئے چاہتے ہیں؟");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "تصویر قسم کا حکم محفوظ ہوگیا ہے.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "تصویر چھانٹیں محفوظ کرنے میں ایک خامی تھی.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "آپ جس فائل کو اپ لوڈ کرنے کی کوشش کر رہے ہیں وہ &#39;اپلوڈ_امیکس_فائلائز&#39; یا &#39;پوسٹ_میکس_ سائز&#39; پی ایچ پی کی ترتیبات سے بڑی ہے۔ ان حدود کو بڑھانے کے لئے اپنے سسٹم کے منتظم سے رابطہ کریں۔");
?>
